Learn R Programming

Rwofost (version 0.8-3)

wofost_soil: WOFOST soil parameters

Description

This function returns a list with soil parameters for the WOFOST model. See this manual https://www.wur.nl/en/show/WOFOST-7.1-User-Manual.htm for their interpretation.

Usage

wofost_soil(name='')

Value

list

Arguments

name

character. Either the name of a soil that comes with the package (see examples) or a filename of a similarly formatted file

See Also

wofost

Examples

Run this code
wofost_soil('')
soil <- wofost_soil('ec1')
str(soil)

Run the code above in your browser using DataLab